@@ -60,8 +60,12 @@ def make_credentials(
             Tags=[{"Key": "Name", "Value": name}, {"Key": "email", "Value": email}],
         )
     except ClientError as err:
+
         user = regex.findall("[\p{L}\p{Z}\p{N}_.:/=+\-@]*", user)
         user = "".join(user)
+        name = regex.findall("[\p{L}\p{Z}\p{N}_.:/=+\-@]*", name)
+        name = "".join(name)
+
         iam_.create_user(
             UserName=user,
             Tags=[{"Key": "Name", "Value": name}, {"Key": "email", "Value": email}],
